@@ -136,7 +136,7 @@ public:
     void removeClientFrame(YFrameWindow *frame);
 
     void updateScreenSize(XEvent *event);
-    void getWorkArea(int *mx, int *my, int *Mx, int *My);
+    void getWorkArea(int *mx, int *my, int *Mx, int *My, int ws);
     void getWorkArea(const YFrameWindow *frame, int *mx, int *my, int *Mx, int *My, int xiscreen = -1);
     void getWorkAreaSize(YFrameWindow *frame, int *Mw,int *Mh);
 
@@ -215,7 +215,7 @@ public:
     bool updateWorkAreaInner();
     void debugWorkArea(const char* prefix);
     void workAreaUpdated();
-    void resizeWindows();
+    void resizeWindows(bool all = true);
 
     void getIconPosition(MiniIcon* iw, int *iconX, int *iconY);
 
