@@ -17,17 +17,17 @@
 class YURL {
 public:
     YURL();
-    YURL(ustring url);
+    YURL(mstring url);
 
-    void operator=(ustring url);
-    static ustring unescape(ustring str);
+    void operator=(mstring url);
+    static mstring unescape(mstring str);
 
-    cstring scheme;
-    cstring user;
-    cstring pass;
-    cstring host;
-    cstring port;
-    cstring path;
+    mstring scheme;
+    mstring user;
+    mstring pass;
+    mstring host;
+    mstring port;
+    mstring path;
 };
 
 #endif
